Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(553)

Unified Diff: components/test_runner/test_runner.h

Issue 1351393002: Make getBluetoothManualChooserEvents() asynchronous. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@lkcr
Patch Set: Go back to the callback interface. Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/html_viewer/web_test_delegate_impl.cc ('k') | components/test_runner/test_runner.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/test_runner/test_runner.h
diff --git a/components/test_runner/test_runner.h b/components/test_runner/test_runner.h
index b8f6284c647c9fc115f4e31938a89e6d1ab6f870..4ea4adeddf2910efe9977fae780411372bbd5736 100644
--- a/components/test_runner/test_runner.h
+++ b/components/test_runner/test_runner.h
@@ -529,8 +529,9 @@ class TestRunner : public WebTestRunner,
// the test program on how to proceed.
void SetBluetoothManualChooser();
- // Returns the events recorded since the last call to this function.
- std::vector<std::string> GetBluetoothManualChooserEvents();
+ // Calls |callback| with a DOMString[] representing the events recorded since
+ // the last call to this function.
+ void GetBluetoothManualChooserEvents(v8::Local<v8::Function> callback);
// Calls the BluetoothChooser::EventHandler with the arguments here. Valid
// event strings are:
@@ -623,6 +624,9 @@ class TestRunner : public WebTestRunner,
const SkBitmap& snapshot);
void DispatchBeforeInstallPromptCallback(scoped_ptr<InvokeCallbackTask> task,
bool canceled);
+ void GetBluetoothManualChooserEventsCallback(
+ scoped_ptr<InvokeCallbackTask> task,
+ const std::vector<std::string>& events);
void CheckResponseMimeType();
void CompleteNotifyDone();
« no previous file with comments | « components/html_viewer/web_test_delegate_impl.cc ('k') | components/test_runner/test_runner.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698